@@ -9,11 +9,11 @@ data_root = 'data/'
 data = dict(
     val=dict(
         type='UAV123Dataset',
-        ann_file='tools/convert_datasets/uav123/uav123_infos.txt',
+        ann_file=data_root + 'UAV123/annotations/uav123_infos.txt',
         img_prefix=data_root + 'UAV123',
         only_eval_visible=False),
     test=dict(
         type='UAV123Dataset',
-        ann_file='tools/convert_datasets/uav123/uav123_infos.txt',
+        ann_file=data_root + 'UAV123/annotations/uav123_infos.txt',
         img_prefix=data_root + 'UAV123',
         only_eval_visible=False))
