@@ -1,5 +1,5 @@
 # Copyright (c) OpenMMLab. All rights reserved.
-import glob
+import os
 import os.path as osp
 import time
 
@@ -63,20 +63,17 @@ class VOTDataset(BaseSOTDataset):
         print('Loading VOT dataset...')
         start_time = time.time()
         data_infos = []
-        ann_file = osp.join(self.img_prefix, 'list.txt')
-        videos_list = np.loadtxt(ann_file, dtype=np.str_)
-        for video_name in videos_list:
-            video_path = osp.join(video_name, 'color')
-            ann_path = osp.join(video_name, 'groundtruth.txt')
-            img_names = glob.glob(
-                osp.join(self.img_prefix, video_path + '/*.jpg'))
-            end_frame_id = max(
-                img_names, key=lambda x: int(osp.basename(x).split('.')[0]))
+        data_infos_str = self.loadtxt(
+            self.ann_file, return_array=False).split('\n')
+        # the first line of annotation file is a dataset comment.
+        for line in data_infos_str[1:]:
+            # compatible with different OS.
+            line = line.strip().replace('/', os.sep).split(',')
             data_info = dict(
-                video_path=video_path,
-                ann_path=ann_path,
-                start_frame_id=1,
-                end_frame_id=int(osp.basename(end_frame_id).split('.')[0]),
+                video_path=line[0],
+                ann_path=line[1],
+                start_frame_id=int(line[2]),
+                end_frame_id=int(line[3]),
                 framename_template='%08d.jpg')
             data_infos.append(data_info)
         print(f'VOT dataset loaded! ({time.time()-start_time:.2f} s)')
@@ -176,7 +173,8 @@ class VOTDataset(BaseSOTDataset):
                 # read one image in the video to get video width and height
                 filename = osp.join(self.img_prefix, data_info['video_path'],
                                     data_info['framename_template'] % 1)
-                img = mmcv.imread(filename)
+                img = mmcv.imread(
+                    filename, file_client_args=self.file_client_args)
                 videos_wh.append((img.shape[1], img.shape[0]))
 
             interval = self.INTERVAL[self.dataset_type] if interval is None \
