@@ -48,18 +48,19 @@ class SelsaAggregator(BaseModule):
             Tensor: The aggregated features of key frame proposals with shape
             [N, C].
         """
-        roi_n = x.shape[0]
-        ref_roi_n = ref_x.shape[0]
+        roi_n, C = x.shape
+        ref_roi_n, _ = ref_x.shape
+        num_c_per_att_block = C // self.num_attention_blocks
 
         x_embed = self.fc_embed(x)
         # [num_attention_blocks, roi_n, C / num_attention_blocks]
         x_embed = x_embed.view(roi_n, self.num_attention_blocks,
-                               -1).permute(1, 0, 2)
+                               num_c_per_att_block).permute(1, 0, 2)
 
         ref_x_embed = self.ref_fc_embed(ref_x)
         # [num_attention_blocks, C / num_attention_blocks, ref_roi_n]
         ref_x_embed = ref_x_embed.view(ref_roi_n, self.num_attention_blocks,
-                                       -1).permute(1, 2, 0)
+                                       num_c_per_att_block).permute(1, 2, 0)
 
         # [num_attention_blocks, roi_n, ref_roi_n]
         weights = torch.bmm(x_embed, ref_x_embed) / (x_embed.shape[-1]**0.5)
@@ -68,10 +69,10 @@ class SelsaAggregator(BaseModule):
         ref_x_new = self.ref_fc(ref_x)
         # [num_attention_blocks, ref_roi_n, C / num_attention_blocks]
         ref_x_new = ref_x_new.view(ref_roi_n, self.num_attention_blocks,
-                                   -1).permute(1, 0, 2)
+                                   num_c_per_att_block).permute(1, 0, 2)
 
         # [roi_n, num_attention_blocks, C / num_attention_blocks]
         x_new = torch.bmm(weights, ref_x_new).permute(1, 0, 2).contiguous()
         # [roi_n, C]
-        x_new = self.fc(x_new.view(roi_n, -1))
+        x_new = self.fc(x_new.view(roi_n, C))
         return x_new
