@@ -2,9 +2,11 @@
 from .base import BaseMultiObjectTracker
 from .byte_track import ByteTrack
 from .deep_sort import DeepSORT
+from .ocsort import OCSORT
 from .qdtrack import QDTrack
 from .tracktor import Tracktor
 
 __all__ = [
-    'BaseMultiObjectTracker', 'Tracktor', 'DeepSORT', 'ByteTrack', 'QDTrack'
+    'BaseMultiObjectTracker', 'Tracktor', 'DeepSORT', 'ByteTrack', 'QDTrack',
+    'OCSORT'
 ]
