@@ -2,11 +2,13 @@
 from .base_tracker import BaseTracker
 from .byte_tracker import ByteTracker
 from .masktrack_rcnn_tracker import MaskTrackRCNNTracker
-from .quasi_dense_embed_tracker import QuasiDenseEmbedTracker
+from .ocsort_tracker import OCSORTTracker
+from .quasi_dense_tao_tracker import QuasiDenseTAOTracker
+from .quasi_dense_tracker import QuasiDenseTracker
 from .sort_tracker import SortTracker
 from .tracktor_tracker import TracktorTracker
 
 __all__ = [
     'BaseTracker', 'TracktorTracker', 'SortTracker', 'MaskTrackRCNNTracker',
-    'ByteTracker', 'QuasiDenseEmbedTracker'
+    'ByteTracker', 'QuasiDenseTracker', 'QuasiDenseTAOTracker', 'OCSORTTracker'
 ]
